/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.utils;

import org.fortiss.tooling.base.model.layout.Dimension;
import org.fortiss.tooling.base.model.layout.ILayoutData;
import org.fortiss.tooling.base.model.layout.ILayoutedModelElement;

/**
 * Utility class for {@link Dimension} layout data.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 3C92A9EB8051A4FA661C64CA936DA905
 */
public final class DimensionUtils {

	/** Returns a {@link Dimension} layout data object with the given key. */
	public static Dimension getDimension(ILayoutedModelElement lobject,
			String key) {
		for (ILayoutData ld : lobject.getLayoutDataList()) {
			if (ld.getKey().equals(key) && ld instanceof Dimension) {
				return (Dimension) ld;
			}
		}
		return null;
	}

	/** Sets a {@link Dimension} layout data object with the given key. */
	public static void setDimension(ILayoutedModelElement lobject, String key,
			int w, int h) {
		Dimension old = getDimension(lobject, key);
		if (old != null) {
			lobject.getLayoutDataList().remove(old);
		}

		Dimension d = LayoutModelElementFactory.createDimension(w, h, key);
		lobject.getLayoutDataList().add(d);
	}
}
